@@ -8,19 +8,14 @@ import jsii
 import publication
 import typing_extensions
 
-import aws_cdk.aws_cloud9._jsii
-import aws_cdk.aws_ec2._jsii
-import aws_cdk.aws_iam._jsii
-import aws_cdk.aws_lambda._jsii
-import aws_cdk.aws_ssm._jsii
-import aws_cdk.core._jsii
+import aws_cdk._jsii
 import constructs._jsii
 
 __jsii_assembly__ = jsii.JSIIAssembly.load(
     "@cdk-use-cases/custom-cloud9-ssm",
-    "1.0.3",
+    "1.1.2",
     __name__[0:-6],
-    "custom-cloud9-ssm@1.0.3.jsii.tgz",
+    "custom-cloud9-ssm@1.1.2.jsii.tgz",
 )
 
 __all__ = [
